aboutsummaryrefslogtreecommitdiff
path: root/src/include/tree.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/tree.h')
-rw-r--r--src/include/tree.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/include/tree.h b/src/include/tree.h
index 6374062..fde66ea 100644
--- a/src/include/tree.h
+++ b/src/include/tree.h
@@ -19,9 +19,11 @@ typedef struct TREE_STRUC {
} comp;
struct { // === DEFINITIONS ===
- char* name; // name of definition
- int mutability; // mutability of definition
+ char* type; // the definition type
+ char** tags; // the definition tags
+ char* name; // the definition name
struct TREE_STRUC* value; // value of definition
+ // :D lines line up :D
} def;
struct { // === CALLS ===